@@ -15,5 +15,6 @@ Load all fleur schema related functions
 """
 from .add_fleur_schema import add_fleur_schema
 from .schema_dict import InputSchemaDict, OutputSchemaDict, schema_dict_version_dispatch
+from .fleur_schema_parser_functions import AttributeType
 
-__all__ = ['add_fleur_schema', 'InputSchemaDict', 'OutputSchemaDict', 'schema_dict_version_dispatch']
+__all__ = ['add_fleur_schema', 'InputSchemaDict', 'OutputSchemaDict', 'schema_dict_version_dispatch', 'AttributeType']
