@@ -277,7 +277,7 @@ def set_attrib_value(xmltree,
     specifications.
     If there are no nodes under the specified xpath a tag can be created with `create=True`.
     The attribute values are converted automatically according to the types of the attribute
-    with :py:func:`~masci_tools.util.xml.converters.convert_attribute_to_xml()` if they
+    with :py:func:`~masci_tools.util.xml.converters.convert_to_xml()` if they
     are not `str` already.
 
     :param xmltree: an xmltree that represents inp.xml
@@ -334,7 +334,7 @@ def set_first_attrib_value(xmltree, schema_dict, attributename, attribv, complex
     specifications.
     If there are no nodes under the specified xpath a tag can be created with `create=True`.
     The attribute values are converted automatically according to the types of the attribute
-    with :py:func:`~masci_tools.util.xml.converters.convert_attribute_to_xml()` if they
+    with :py:func:`~masci_tools.util.xml.converters.convert_to_xml()` if they
     are not `str` already.
 
     :param xmltree: an xmltree that represents inp.xml
@@ -369,7 +369,7 @@ def set_text(xmltree, schema_dict, tag_name, text, complex_xpath=None, occurrenc
     further specifications. By default the text will be set on all nodes returned for the specified xpath.
     If there are no nodes under the specified xpath a tag can be created with `create=True`.
     The text values are converted automatically according to the types
-    with :py:func:`~masci_tools.util.xml.converters.convert_text_to_xml()` if they
+    with :py:func:`~masci_tools.util.xml.converters.convert_to_xml()` if they
     are not `str` already.
 
     :param xmltree: an xmltree that represents inp.xml
@@ -410,7 +410,7 @@ def set_first_text(xmltree, schema_dict, attributename, attribv, complex_xpath=N
     further specifications. By default the text will be set on all nodes returned for the specified xpath.
     If there are no nodes under the specified xpath a tag can be created with `create=True`.
     The text values are converted automatically according to the types
-    with :py:func:`~masci_tools.util.xml.converters.convert_text_to_xml()` if they
+    with :py:func:`~masci_tools.util.xml.converters.convert_to_xml()` if they
     are not `str` already.
 
     :param xmltree: an xmltree that represents inp.xml
@@ -540,7 +540,7 @@ def set_species_label(xmltree, schema_dict, atom_label, attributedict, create=Fa
     if atom_label == 'all':
         return set_species(xmltree, schema_dict, 'all', attributedict, create=create)
 
-    atom_label = '{: >20}'.format(atom_label)
+    atom_label = f'{atom_label: >20}'
     all_groups = eval_simple_xpath(xmltree, schema_dict, 'atomGroup', list_return=True)
 
     species_to_set = set()
@@ -647,7 +647,7 @@ def shift_value_species_label(xmltree, schema_dict, atom_label, attributename, v
     tag_base_xpath, attributename = split_off_attrib(attr_base_path)
 
     if atom_label != 'all':
-        atom_label = '{: >20}'.format(atom_label)
+        atom_label = f'{atom_label: >20}'
     all_groups = eval_simple_xpath(xmltree, schema_dict, 'atomGroup', list_return=True)
 
     species_to_set = set()
@@ -705,7 +705,7 @@ def set_atomgroup_label(xmltree, schema_dict, atom_label, attributedict, create=
         xmltree = set_atomgroup(xmltree, schema_dict, attributedict, position=None, species='all')
         return xmltree
 
-    atom_label = '{: >20}'.format(atom_label)
+    atom_label = f'{atom_label: >20}'
     all_groups = eval_simple_xpath(xmltree, schema_dict, 'atomGroup', list_return=True)
 
     species_to_set = set()
@@ -844,7 +844,7 @@ def set_inpchanges(xmltree, schema_dict, change_dict, path_spec=None):
         if key == 'xcFunctional':
             key = 'name'
 
-        if key not in schema_dict['attrib_types'] and key not in schema_dict['simple_elements']:
+        if key not in schema_dict['attrib_types'] and key not in schema_dict['text_tags']:
             raise ValueError(f"You try to set the key:'{key}' to : '{change_value}', but the key is unknown"
                              ' to the fleur plug-in')
 
@@ -903,7 +903,7 @@ def set_kpointlist(xmltree,
     :returns: an xmltree of the inp.xml file with changes.
     """
     from masci_tools.util.schema_dict_util import evaluate_attribute
-    from masci_tools.util.xml.converters import convert_text_to_xml, convert_attribute_to_xml
+    from masci_tools.util.xml.converters import convert_to_xml
     from masci_tools.util.xml.xml_setters_basic import xml_delete_tag
     from lxml import etree
     import numpy as np
@@ -933,12 +933,12 @@ def set_kpointlist(xmltree,
 
     new_kpo = etree.Element('kPointList', name=name, count=f'{nkpts:d}', type=kpoint_type)
     for indx, (kpoint, weight) in enumerate(zip(kpoints, weights)):
-        weight, _ = convert_attribute_to_xml(weight, ['float', 'float_expression'])
+        weight, _ = convert_to_xml(weight, schema_dict, 'weight')
         if indx in special_labels:
             new_k = etree.Element('kPoint', weight=weight, label=special_labels[indx])
         else:
             new_k = etree.Element('kPoint', weight=weight)
-        text, _ = convert_text_to_xml(kpoint, [{'type': ['float', 'float_expression'], 'length': 3}])
+        text, _ = convert_to_xml(kpoint, schema_dict, 'kpoint', text=True)
         new_k.text = text
         new_kpo.append(new_k)
 
@@ -965,7 +965,7 @@ def set_kpointlist_max4(xmltree, schema_dict, kpoints, weights):
     :returns: an xmltree of the inp.xml file with changes.
     """
     from masci_tools.util.schema_dict_util import eval_simple_xpath
-    from masci_tools.util.xml.converters import convert_text_to_xml, convert_attribute_to_xml
+    from masci_tools.util.xml.converters import convert_to_xml
     from lxml import etree
     import numpy as np
 
@@ -985,9 +985,9 @@ def set_kpointlist_max4(xmltree, schema_dict, kpoints, weights):
 
     new_kpo = etree.Element('kPointList', posScale='1.0', weightScale='1.0', count=f'{nkpts:d}')
     for kpoint, weight in zip(kpoints, weights):
-        weight, _ = convert_attribute_to_xml(weight, ['float', 'float_expression'])
+        weight, _ = convert_to_xml(weight, schema_dict, 'weight')
         new_k = etree.Element('kPoint', weight=weight)
-        text, _ = convert_text_to_xml(kpoint, [{'type': ['float', 'float_expression'], 'length': 3}])
+        text, _ = convert_to_xml(kpoint, schema_dict, 'kpoint', text=True)
         new_k.text = text
         new_kpo.append(new_k)
 
@@ -1127,7 +1127,7 @@ def set_kpath_max4(xmltree, schema_dict, kpath, count, gamma=False):
     :returns: an xmltree of the inp.xml file with changes.
     """
     from masci_tools.util.schema_dict_util import tag_exists
-    from masci_tools.util.xml.converters import convert_to_fortran_bool, convert_text_to_xml
+    from masci_tools.util.xml.converters import convert_to_fortran_bool, convert_to_xml
     from masci_tools.util.xml.xml_setters_basic import xml_replace_tag
     from lxml import etree
 
@@ -1137,10 +1137,10 @@ def set_kpath_max4(xmltree, schema_dict, kpath, count, gamma=False):
         xmltree = create_tag(xmltree, schema_dict, 'kPointCount', contains='altKPoint', create_parents=True)
         xmltree = set_first_attrib_value(xmltree, schema_dict, 'purpose', 'bands')
 
-    new_kpo = etree.Element('kPointCount', count='{}'.format(count), gamma='{}'.format(convert_to_fortran_bool(gamma)))
+    new_kpo = etree.Element('kPointCount', count=f'{count}', gamma=f'{convert_to_fortran_bool(gamma)}')
     for label, coord in kpath.items():
-        new_k = etree.Element('specialPoint', name='{}'.format(label))
-        text, _ = convert_text_to_xml(coord, [{'type': ['float', 'float_expression'], 'length': 3}])
+        new_k = etree.Element('specialPoint', name=f'{label}')
+        text, _ = convert_to_xml(coord, schema_dict, 'kpoint', text=True)
         new_k.text = text
         new_kpo.append(new_k)
 
